@@ -5,7 +5,7 @@
 	if(length(modeldiff$change) != 0) {
 		thA <- getDiffThetaChange(th, mod)
 		th <- thA$th
-		.currModel@parorderchange <<- thA$parorder
+		mod@parorderchange <- thA$parorder
 	}
 	if(length(modeldiff$free)!=0 || length(modeldiff$add) !=0)
 		for(diff in append(mod@modeldiffs$free, mod@modeldiffs$add)){ 
@@ -15,10 +15,13 @@
 			  model <- modellist[[diff$dataset[1]]]
 			  removepar <- sort(append(fixed[[diff$what]],prel[[diff$what]]))
 			  if(length(diff$ind) == 2) {
-			     partmp <- slot(model, 
-	                     diff$what)[[diff$ind[1]]][diff$ind[2]]
-			    whichfree <- if(diff$ind[1] > 1) 
-			    (length(unlist(slot(model, diff$what))[[1:(diff$ind[1] - 1)]])) + diff$ind[2] else diff$ind[2]
+			    whichfree <- diff$ind[2]
+			    if(diff$ind[1] > 1) {
+			       slW<-slot(model, diff$what)
+			       whichfree <- whichfree + sum(unlist(lapply(slW, length))[1:(diff$ind[1]-1)]) 
+			    }
+			    partmp <- slot(model, diff$what)[[diff$ind[1]]][diff$ind[2]]
+
 			  }
 			  else { 
 			     partmp <- slot(model, 
@@ -79,7 +82,7 @@
 			}
 	        }
        }
-       .currModel@parorderdiff <<- parorder
-       th
+       mod@parorderdiff <- parorder
+       list(theta = th, mod = mod)
 }
 
