@@ -19,7 +19,7 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
 	clpType = "character", clpequspecBD = "list", compnames = "vector", 
 	getXsuper = "logical", usecompnames0 = "logical", 
 	usecompnamesequ = "logical", autoclp0 = "list", cohcol = "numeric",
-        weightList = "list"), 
+        weightList = "list", outMat = "matrix", satMat = "matrix"), 
         prototype = list(psi.df = matrix(), psi.weight = matrix(), 
             x = vector(), nt = integer(), x2 = vector(), nl = integer(), 
             C2 = matrix(), E2 = matrix(), sigma = numeric(), 
@@ -39,8 +39,7 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
 	    clpType = "", clpequspecBD = list(), compnames = vector(),
 	    getXsuper = FALSE, usecompnames0 = FALSE,  
 	    usecompnamesequ = FALSE, autoclp0 = list(), cohcol = 0,
-            weightList = list()))
-
+            weightList = list(), outMat = matrix(), satMat = matrix() ))
 
 setClass("kin", representation("dat", kinpar = "vector", specpar =
 "list", seqmod = "logical", irf = "logical", mirf = "logical", reftau
