@@ -3,7 +3,7 @@ function (data, sample = 1, sample_time = 1, sample_lambda = 1,
     sel_time = vector(), sel_lambda = vector(), baselinetime = vector(), 
     baselinelambda = vector(), scalx = NULL, scalx2 = NULL, 
     sel_lambda_ab = vector(), sel_time_ab = vector(), rm_x2 = vector(), 
-    rm_x = vector(), svdResid = list(), numV = 0) 
+    rm_x = vector(), svdResid = list(), numV = 0, sel_special = list() ) 
 {
     ## Note that the options are _not_ compatible with each other
     ## call preProcess repeatedly for consistency
@@ -11,7 +11,8 @@ function (data, sample = 1, sample_time = 1, sample_lambda = 1,
   dataN <- sample_sel(data = data, sample = sample, sample_time = 
                       sample_time, sample_lambda = sample_lambda, 
                       sel_time = sel_time, sel_lambda = sel_lambda, 
-                      sel_lambda_ab = sel_lambda_ab, sel_time_ab = sel_time_ab)
+                      sel_lambda_ab = sel_lambda_ab,
+                      sel_time_ab = sel_time_ab, sel_special = sel_special)
   if (length(baselinelambda) != 0) 
     dataN <- baseCorlambda(dataN, baselinelambda)
   if (length(baselinetime) != 0) 
@@ -19,12 +20,12 @@ function (data, sample = 1, sample_time = 1, sample_lambda = 1,
   if (length(rm_x2) != 0) { 
     dataN@psi.df <- dataN@psi.df[,-rm_x2] 
     dataN@x2 <-  dataN@x2[-rm_x2]
-	 dataN@nl <- dataN@nl - length(rm_x2)
+    dataN@nl <- dataN@nl - length(rm_x2)
   }
   if (length(rm_x) != 0) { 
     dataN@psi.df <- dataN@psi.df[-rm_x,] 
     dataN@x <-  dataN@x[-rm_x]
-	 dataN@nt <- dataN@nt - length(rm_x)
+    dataN@nt <- dataN@nt - length(rm_x)
   }
   if (!is.null(scalx)) 
         dataN@x <- dataN@x * scalx
